@@ -22,6 +22,7 @@ class QonsoExtractorBouygues(QonsoExtractor):
       DebugLog("QonsoExtractorBouygues::Authenticate")
       
       self.SetStatus('INFO', 'Authentification...')
+      self.progress = 66
 
       request = self.PrepareRequest()
       request.setUrl( QtCore.QUrl(self.urlAuth+idCorrelation) ) 
@@ -135,7 +136,7 @@ class QonsoExtractorBouygues(QonsoExtractor):
       # Conso Voix
       DebugLog("_______________________________________________\nConso voix")
       DebugLog("-----------------------------------------------\n")
-      res = re.search("(?:Vous n'avez pas encore profité de)? votre [Ff]orfait (.+?) de %smin" %(self.hmReS), html)
+      res = re.search("(?:Vous n'avez pas encore profité de)? votre [Ff]orfait (.+?) de ((?:\s*\d{1,2}\s*[Hh])?\s*(?:\d{1,3}\s*(?:mi?n)))" , html)
       if res:
          DebugLog(res.groups())
          self.model.SetForfait( res.group(1) )
