@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 import os, sys, time
-from PyQt4 import QtGui, QtCore, Qt
+from PyQt4 import QtGui, QtCore
 import QonsoFactory
 from QonsoModel import QonsoModel
 from DlgConfig import DlgConfig
